@@ -1,4 +1,4 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl -w
 # (c) 2007, Joe Perches <joe@perches.com>
 #           created from checkpatch.pl
 #
@@ -8,10 +8,9 @@
 # usage: perl scripts/get_maintainer.pl [OPTIONS] <patch>
 #        perl scripts/get_maintainer.pl [OPTIONS] -f <file>
 #
-# SPDX-License-Identifier: GPL-2.0-only
+# Licensed under the terms of the GNU GPL License version 2
 
 use strict;
-use warnings;
 
 my $P = $0;
 my $V = '0.26';
